==> razorqt_0.4.1.orig.tar.xz: razorqt-0.4.1/razorqt-panel/plugin-taskbar/translations/taskbar_el_GR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="el_GR">
<context>
    <name>RazorTaskButton</name>
    <message>
        <location filename="../razortaskbutton.cpp" line="372"/>
        <source>Application</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="405"/>
        <source>To &amp;Desktop</source>
        <translation>Στην Επι&amp;φάνεια Εργασίας</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="407"/>
        <source>&amp;All Desktops</source>
        <translation>Ό&amp;λες οι Επιφάνειες Εργασίας</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="415"/>
        <source>Desktop &amp;%1</source>
        <translation>Επιφάνεια Εργασίας &amp;%1</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="422"/>
        <source>&amp;To Current Desktop</source>
        <translation>Σ&amp;την Τρέχουσα Επιφάνεια Εργασίας</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="431"/>
        <source>Ma&amp;ximize</source>
        <translation>&amp;Μεγιστοποίηση</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="440"/>
        <source>Maximize vertically</source>
        <translation>Μεγιστοποίηση κάθετα</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="445"/>
        <source>Maximize horizontally</source>
        <translation>Μεγιστοποίηση οριζόντια</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="451"/>
        <source>&amp;Restore</source>
        <translation>&amp;Επαναφορά</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="455"/>
        <source>Mi&amp;nimize</source>
        <translation>Ελα&amp;χιστοποίηση</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="461"/>
        <source>Roll down</source>
        <translation>Κύλιση κάτω</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="467"/>
        <source>Roll up</source>
        <translation>Κύλιση επάνω</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="476"/>
        <source>&amp;Layer</source>
        <translation>Επίπε&amp;δο</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="478"/>
        <source>Always on &amp;top</source>
        <translation>Πάντα ε&amp;πάνω</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="483"/>
        <source>&amp;Normal</source>
        <translation>&amp;Κανονικό</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="488"/>
        <source>Always on &amp;bottom</source>
        <translation>Πάντα από &amp;κάτω</translation>
    </message>
    <message>
        <location filename="../razortaskbutton.cpp" line="496"/>
        <source>&amp;Close</source>
        <translation>&amp;Κλείσιμο</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="14"/>
        <source>Razor Task Manager Settings</source>
        <translation>Ρυθμίσεις Διαχειριστή Εργασιών Razor</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="20"/>
        <source>Window List Content</source>
        <translation type="unfinished">Παράθυρο Λίστας Περιεχομένων</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="26"/>
        <source>Show windows from current desktop</source>
        <translation>Εμφάνιση παραθύρων από την τρέχουσα επιφάνεια εργασίας</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="29"/>
        <location filename="../razortaskbarconfiguration.ui" line="39"/>
        <source>wlcB</source>
        <translation>wlcB</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="36"/>
        <source>Show windows from all desktops</source>
        <translation>Εμφάνιση παραθύρων από όλες τις επιφάνειες εργασίας</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="49"/>
        <source>Window List Appearance</source>
        <translation type="unfinished">Παράθυρο Λίστας Εμφάνισης</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="55"/>
        <source>Button style</source>
        <translation>Στυλ πλήκτρου</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.ui" line="65"/>
        <source>Max button width</source>
        <translation>Μέγιστο πλάτος πλήκτρου</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="43"/>
        <source>Icon and text</source>
        <translation>Εικόνα και κείμενο</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="44"/>
        <source>Only icon</source>
        <translation>Μόνο εικόνα</translation>
    </message>
    <message>
        <location filename="../razortaskbarconfiguration.cpp" line="45"/>
        <source>Only text</source>
        <translation>Μόνο κείμενο</translation>
    </message>
</context>
</TS>

==> razorqt_0.5.2.orig.tar.xz: razorqt-0.5.2/razorqt-panel/plugin-taskbar/translations/taskbar_el_GR.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="el_GR" version="2.0">
<context>
    <name>RazorTaskButton</name>
    <message>
        <source>Application</source>
        <translation>Εφαρμογή</translation>
    </message>
    <message>
        <source>To &amp;Desktop</source>
        <translation>Στην επι&amp;φάνεια εργασίας</translation>
    </message>
    <message>
        <source>&amp;All Desktops</source>
        <translation>Ό&amp;λες οι επιφάνειες εργασίας</translation>
    </message>
    <message>
        <source>Desktop &amp;%1</source>
        <translation>Επιφάνεια εργασίας &amp;%1</translation>
    </message>
    <message>
        <source>&amp;To Current Desktop</source>
        <translation>Στ&amp;ην τρέχουσα επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Ma&amp;ximize</source>
        <translation>&amp;Μεγιστοποίηση</translation>
    </message>
    <message>
        <source>Maximize vertically</source>
        <translation>Μεγιστοποίηση κάθετα</translation>
    </message>
    <message>
        <source>Maximize horizontally</source>
        <translation>Μεγιστοποίηση οριζόντια</translation>
    </message>
    <message>
        <source>&amp;Restore</source>
        <translation>&amp;Επαναφορά</translation>
    </message>
    <message>
        <source>Mi&amp;nimize</source>
        <translation>Ελα&amp;χιστοποίηση</translation>
    </message>
    <message>
        <source>Roll down</source>
        <translation>Κύλιση κάτω</translation>
    </message>
    <message>
        <source>Roll up</source>
        <translation>Κύλιση επάνω</translation>
    </message>
    <message>
        <source>&amp;Layer</source>
        <translation>Στ&amp;ρώμα</translation>
    </message>
    <message>
        <source>Always on &amp;top</source>
        <translation>Πάντα ε&amp;πάνω</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>Κα&amp;νονικό</translation>
    </message>
    <message>
        <source>Always on &amp;bottom</source>
        <translation>Πάντα &amp;κάτω</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Κλεί&amp;σιμο</translation>
    </message>
</context>
<context>
    <name>RazorTaskbarConfiguration</name>
    <message>
        <source>Razor Task Manager Settings</source>
        <translation>Ρυθμίσεις διαχειριστή εργασιών Razor</translation>
    </message>
    <message>
        <source>Window List Content</source>
        <translation>Περιεχόμενο λίστας παραθύρου</translation>
    </message>
    <message>
        <source>Show windows from current desktop</source>
        <translation>Εμφάνιση παραθύρων από την τρέχουσα επιφάνεια εργασίας</translation>
    </message>
    <message>
        <source>Show windows from all desktops</source>
        <translation>Εμφάνιση παραθύρων από όλες τις επιφάνειες εργασίας</translation>
    </message>
    <message>
        <source>Window List Appearance</source>
        <translation>Εμφάνιση λίστας παραθύρων</translation>
    </message>
    <message>
        <source>Button style</source>
        <translation>Στυλ πλήκτρου</translation>
    </message>
    <message>
        <source>Max button width</source>
        <translation>Μέγιστο πλάτος πλήκτρου</translation>
    </message>
    <message>
        <source>Close on middle-click</source>
        <translation>Κλείσιμο με μεσαίο κλικ</translation>
    </message>
    <message>
        <source>Icon and text</source>
        <translation>Εικόνα και κείμενο</translation>
    </message>
    <message>
        <source>Only icon</source>
        <translation>Μόνο εικόνα</translation>
    </message>
    <message>
        <source>Only text</source>
        <translation>Μόνο κείμενο</translation>
    </message>
</context>
</TS>
